==> apache-artemis-2.33.0-source-release.tar.gz: apache-artemis-2.33.0/artemis-server/src/test/java/org/apache/activemq/artemis/spi/core/security/jaas/kubernetes/model/ServiceAccountPrincipalTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.activemq.artemis.spi.core.security.jaas.kubernetes.model;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertNull;

import org.apache.activemq.artemis.spi.core.security.jaas.ServiceAccountPrincipal;
import org.junit.Test;

public class ServiceAccountPrincipalTest {

   @Test
   public void testFullName() {
      String name = "system:serviceaccounts:some-ns:some-sa";

      ServiceAccountPrincipal principal = new ServiceAccountPrincipal(name);

      assertEquals("some-ns", principal.getNamespace());
      assertEquals("some-sa", principal.getSaName());
      assertEquals(name, principal.getName());
   }

   @Test
   public void testSimpleName() {
      String name = "foo";

      ServiceAccountPrincipal principal = new ServiceAccountPrincipal(name);

      assertEquals(name, principal.getName());
      assertNull(principal.getSaName());
      assertNull(principal.getNamespace());
   }

}

==> apache-artemis-2.42.0-source-release.tar.gz: apache-artemis-2.42.0/artemis-server/src/test/java/org/apache/activemq/artemis/spi/core/security/jaas/kubernetes/model/ServiceAccountPrincipalTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.activemq.artemis.spi.core.security.jaas.kubernetes.model;

import static org.junit.jupiter.api.Assertions.assertEquals;
import static org.junit.jupiter.api.Assertions.assertNull;

import org.apache.activemq.artemis.spi.core.security.jaas.ServiceAccountPrincipal;
import org.junit.jupiter.api.Test;

public class ServiceAccountPrincipalTest {

   @Test
   public void testFullName() {
      String name = "system:serviceaccounts:some-ns:some-sa";

      ServiceAccountPrincipal principal = new ServiceAccountPrincipal(name);

      assertEquals("some-ns", principal.getNamespace());
      assertEquals("some-sa", principal.getSaName());
      assertEquals(name, principal.getName());
   }

   @Test
   public void testSimpleName() {
      String name = "foo";

      ServiceAccountPrincipal principal = new ServiceAccountPrincipal(name);

      assertEquals(name, principal.getName());
      assertNull(principal.getSaName());
      assertNull(principal.getNamespace());
   }

}
